==> raphson_mp-2.5.0.tar.gz: raphson_mp-2.5.0/raphson_mp/static/js/player/coversize.js <==
// Ensures combined height of album cover and lyrics box never exceed 100vh

class CoverSize {
    #lyricsBox = /** @type {HTMLDivElement} */ (document.getElementById('lyrics-box'));
    #coverBox = /** @type {HTMLDivElement} */ (document.getElementById('album-cover-box'));
    #body = /** @type {HTMLBodyElement} */ (document.getElementsByTagName("body")[0]);
    /** @type {number | null} */
    #timeoutId = null;

    constructor() {
        const resizeObserver = new ResizeObserver(() => this.#observerCallback());
        resizeObserver.observe(this.#lyricsBox);
        resizeObserver.observe(this.#body);
    }

    /**
     * @param {string} value
     */
    #setMaxHeight(value) {
        this.#coverBox.style.maxHeight = value;
        this.#coverBox.style.maxWidth = value;
        this.#lyricsBox.style.maxWidth = value;
        console.debug('coversize: max height changed:', value);
    }

    resizeCover() {
        // Do not set max height in single column interface
        if (this.#body.clientWidth <= 950) {
            this.#setMaxHeight('none');
            return;
        }

        if (this.#lyricsBox.hidden) {
            // No lyrics
            this.#setMaxHeight(`calc(100vh - 2*var(--gap))`);
            return;
        }

        this.#setMaxHeight(`calc(100vh - 3*var(--gap) - ${this.#lyricsBox.clientHeight}px)`);
    }

    #observerCallback() {
        // Throttle function calls
        if (this.#timeoutId) {
            clearTimeout(this.#timeoutId);
        }

        this.#timeoutId = setTimeout(() => this.resizeCover(), 100);
    }
}

export const coverSize = new CoverSize();

==> raphson_mp-2.6.1.tar.gz: raphson_mp-2.6.1/raphson_mp/static/js/player/coversize.js <==
// Ensures combined height of album cover and lyrics box never exceed 100vh

class CoverSize {
    #lyricsBox = /** @type {HTMLDivElement} */ (document.getElementById('lyrics-box'));
    #coverBox = /** @type {HTMLDivElement} */ (document.getElementById('album-cover-box'));
    /** @type {number | null} */
    #timeoutId = null;

    constructor() {
        const resizeObserver = new ResizeObserver(() => this.#observerCallback());
        resizeObserver.observe(this.#lyricsBox);
        resizeObserver.observe(document.body);
    }

    /**
     * @param {string} value
     */
    #setMaxHeight(value) {
        this.#coverBox.style.maxHeight = value;
        this.#coverBox.style.maxWidth = value;
        this.#lyricsBox.style.maxWidth = value;
        console.debug('coversize: max height changed:', value);
    }

    resizeCover() {
        // Do not set max height in single column interface
        if (document.body.clientWidth <= 950) {
            this.#setMaxHeight('none');
            return;
        }

        if (this.#lyricsBox.hidden) {
            // No lyrics
            this.#setMaxHeight(`calc(100vh - 2*var(--gap))`);
            return;
        }

        this.#setMaxHeight(`calc(100vh - 3*var(--gap) - ${this.#lyricsBox.clientHeight}px)`);
    }

    #observerCallback() {
        // Throttle function calls
        if (this.#timeoutId) {
            clearTimeout(this.#timeoutId);
        }

        this.#timeoutId = setTimeout(() => this.resizeCover(), 100);
    }
}

export const coverSize = new CoverSize();
